function h=figure_streamtube(tract,para_cell,color)

%function h=figure_streamtube(tract,para_cell,color)
%
% tract: n tract coordinates given as a matrix of size 3 x n. 
% para_cell: radius of tube
% color: color of tube
%
%
% (C) Moo K. Chung 2009
%     mkchung@wisc.edu
%     Department of Biostatistics and Medical Infomatics
%     Waisman Laboratory for Brain Imaging and Behavior
%     University of Wisconsin-Madison
%
% mkchung@wisc.edu
%
% Update history: June 16, 2010
%                 September 30, 2009


tract_cell={[tract']};

daspect([0.5 0.5 0.5])
%h=streamribbon(tract_cell,para_cell);
h=streamtube(tract_cell,para_cell);

set(h,'EdgeColor','none','FaceColor',color, 'CDataMapping','direct','AmbientStrength',0.3) %0.3

axis tight
%shading interp;
view(3);
camlight;
material metal
lighting  gouraud
set(gcf,'Color','w')


%set(h,'EdgeColor','none','FaceColor','r', 'AmbientStrength',0.5)


